Welcome to django-recurring's documentation!
============================================

django-recurring is a powerful Django app that allows you to create and manage recurring events using the dateutil rruleset functionality. It provides a flexible and intuitive way to handle complex recurrence patterns in your Django projects.

See the :doc:`admin screenshots <admin>` to get a quick idea of what it can do.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   readme
   installation
   usage
   admin
   examples
   management_commands
   modules
   contributing
   history

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
